@@ -241,7 +241,7 @@ class PHPParserVersion74Test extends AbstractTest
         /** @var ASTScalarType $parameters */
         $type = $closure->getChild(1);
         $this->assertInstanceOf('PDepend\\Source\\AST\\ASTScalarType', $type);
-        $this->assertSame('int',$type->getImage());
+        $this->assertSame('int', $type->getImage());
         /** @var ASTReturnStatement $parameters */
         $return = $closure->getChild(2);
         $this->assertInstanceOf('PDepend\\Source\\AST\\ASTReturnStatement', $return);
@@ -392,6 +392,11 @@ class PHPParserVersion74Test extends AbstractTest
         $this->assertSame('A', $nodes[1]->getImage());
     }
 
+    public function testReadOnlyNamedImport()
+    {
+        $this->assertFalse($this->parseCodeResourceForTest()->current());
+    }
+
     /**
      * @expectedException \PDepend\Source\Parser\UnexpectedTokenException
      * @expectedExceptionMessage Unexpected token: ), line: 8, col: 27
@@ -401,6 +406,24 @@ class PHPParserVersion74Test extends AbstractTest
         $this->getFirstClassForTestCase();
     }
 
+    /**
+     * @expectedException \PDepend\Source\Parser\UnexpectedTokenException
+     * @expectedExceptionMessage Unexpected token: ), line: 5, col: 32
+     */
+    public function testTrailingCommaInClosureUseListError()
+    {
+        $this->parseCodeResourceForTest();
+    }
+
+    /**
+     * @expectedException \PDepend\Source\Parser\UnexpectedTokenException
+     * @expectedExceptionMessage Unexpected token: ), line: 4, col: 43
+     */
+    public function testTrailingCommaInParameterList()
+    {
+        $this->getFirstMethodForTestCase();
+    }
+
     /**
      * @param \PDepend\Source\Tokenizer\Tokenizer $tokenizer
      * @param \PDepend\Source\Builder\Builder $builder
